#!/bin/bash

##
## Wrapper script used to start the server in the background.
##
## This script also allows for the restarting of the server
## When the upgrade exit code 128 is returned from a running instance.
##
## Author: Arthur Heffern
## Maintainer: Michael Yara
## Last Modified: Jan 6, 2014
##

# Trap SIGHUP
trap "" SIGHUP

# Setup variables for execution
BASEDIR=`dirname ${0}`
cd $BASEDIR
SERVERSCRIPTNAME=`ls -1 *Server.sh | head -n 1`
BASENAME=`basename ${SERVERSCRIPTNAME} .sh`
. ./config-vars.sh

#
# Function used to start the server by calling the main server script.
#
function startServer {
	SERVERSCRIPTNAME=`ls -1 *Server.sh | head -n 1`
	/bin/bash ${SERVERSCRIPTNAME} start
}

# If this is the entry call to this script re-execute the script
# With "--" in order to run another instance in the background.
if [ x${1} != "x--" ] ; then	
	${0} -- ${BASENAME} &
	
	# Sleep for 2 seconds so that the shell prompt does not get hidden on exit
	sleep 2
	
	exit 0;
fi

# Start the server
startServer

# If the main server script exited with code 128 restart the server
# as an upgrade was just applied.
while [ $? -eq 128 ]; do
	startServer
done

exit 0

